%define fname		vid.stab
%define	major		1.1
%define	libname		%mklibname vidstab %{major}
%define	develname	%mklibname vidstab -d
%define staticname	%mklibname -s -d vidstab

%define gitver		git20190213
%define rel		5

%bcond_with		use_clang

Summary:	Video stabilization library
Name:		vidstab
Version:	1.1.0
Release:	%mkrel %{?gitver:2.%gitver.}%{rel}
License:	GPLv2
Group:		Video/Utilities
Url:		https://github.com/georgmartius/vid.stab
Source0:	%{fname}-%{version}%{?gitver:-1.%gitver}.tar.gz
BuildRequires:	cmake
BuildRequires:	libgomp-devel
%if %{with use_clang}
BuildRequires:	clang
BuildRequires:	libomp
BuildRequires:	libomp-devel
%endif

%description
A video stabilization library which can be plugged-in with ffmpeg and
Transcode.

A video acquired using a hand-held camera or a camera mounted on a
vehicle, typically suffers from undesirable shakes and
jitters. Activities like surfing, skiing, riding and walking while
shooting videos are especially prone to erratic camera shakes. Vidstab
targets these video contents to help create smoother and stable
videos.

%package -n	%{libname}
Summary:	A video stabilization library
Group:		System/Libraries

%description -n	%{libname}
A video stabilization library which can be plugged-in with ffmpeg and
Transcode.

This package contains the shared libraries of vid.stab.

%package -n	%{develname}
Summary:	Development files for the vid.stab library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{libname}-devel = %{version}-%{release}
Provides:	vidstab-devel = %{version}-%{release}

%description -n	%{develname}
A video stabilization library which can be plugged-in with ffmpeg and
Transcode.

Install this package if you want to compile apps with vid.stab support.

%package -n	%{staticname}
Summary:	Static libraries for linking to vid.stab
Group:		Development/C
Requires:	%{develname} = %{version}-%{release}
Provides:	%{name}-static = %{version}-%{release}
Provides:	vistab-static-devel = %{version}-%{release}

%description -n	%{staticname}
Static libraries for vid.stab.

%prep
%autosetup -n %{fname}-%{version} -p1
%if %{with use_clang}
perl -pi -e 's@-lgomp@-fopenmp@g' CMakeLists.txt
perl -pi -e 's@vidstab gomp@vidstab omp@g' CMakeLists.txt
%endif

%build
%if %{with use_clang}
%global optflags %{optflags} -fopenmp
%global ldflags %{ldflags} -fopenmp
%endif

# build static libs in two steps (because actually cmake doesn't shared ans static libs at the same time)
%cmake	\
	-DUSE_OMP:BOOL=ON \
%ifarch %{ix86}
	-DSSE2_FOUND:BOOL=OFF \
	-DSSE3_FOUND:BOOL=OFF \
	-DSSE4_1_FOUND:BOOL=OFF \
	-DSSSE3_FOUND:BOOL=OFF \
%endif
	-DBUILD_STATIC_LIBS:BOOL=ON \
	-DBUILD_SHARED_LIBS:BOOL=OFF
%cmake_build

cp -p %{_vpath_builddir}/libvidstab.a .

make clean -C %{_vpath_builddir}

%cmake	\
	-DUSE_OMP:BOOL=ON \
%ifarch %{ix86}
	-DSSE2_FOUND:BOOL=OFF \
	-DSSE3_FOUND:BOOL=OFF \
	-DSSE4_1_FOUND:BOOL=OFF \
	-DSSSE3_FOUND:BOOL=OFF \
%endif
	-DBUILD_STATIC_LIBS:BOOL=OFF \
	-DBUILD_SHARED_LIBS:BOOL=ON
%cmake_build

%install
%cmake_install
install -m 644 libvidstab.a %{buildroot}%{_libdir}

%files -n %{libname}
%{_libdir}/libvidstab.so.%{major}

%files -n %{develname}
%doc README.md LICENSE Changelog
%{_libdir}/libvidstab.so
%dir %{_includedir}/vid.stab
%{_includedir}/vid.stab/*.h
%{_libdir}/pkgconfig/vidstab.pc

%files -n %{staticname}
%{_libdir}/*.a



%changelog
* Sat Feb 15 2020 wally <wally> 1.1.0-2.git20190213.5.mga8
+ Revision: 1526651
- build with new cmake macros
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Fri May 17 2019 ghibo <ghibo> 1.1.0-2.git20190213.4.mga7
+ Revision: 1398206
- Make description less verbose

* Fri May 17 2019 ghibo <ghibo> 1.1.0-2.git20190213.3.mga7
+ Revision: 1398174
- Fix Release number with mkrel (spotted by David Geiger)

* Fri May 17 2019 ghibo <ghibo> 1.1.0-1.git201902132.mga7
+ Revision: 1398157
- Switch to use gcc
- Add libomp to BuildRequires
- imported package vidstab


* Fri May 17 2019 ghibo <ghibo> 1.1.0-1.git201902131.mga7
- Initial release.
